Contribution Guidelines
=======================

Before proposing a pull request, please read our [Contributor's Guide][1].

  [1]: https://toil.readthedocs.io/en/master/contributing/contributing.html#contributing "Toil Contributor's Guide"
